You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@poi.apache.org by se...@apache.org on 2011/08/22 13:51:57 UTC

svn commit: r1160219 - /poi/trunk/src/scratchpad/src/org/apache/poi/hwpf/converter/AbstractWordConverter.java

Author: sergey
Date: Mon Aug 22 11:51:56 2011
New Revision: 1160219

URL: http://svn.apache.org/viewvc?rev=1160219&view=rev
Log:
better log message

Modified:
    poi/trunk/src/scratchpad/src/org/apache/poi/hwpf/converter/AbstractWordConverter.java

Modified: poi/trunk/src/scratchpad/src/org/apache/poi/hwpf/converter/AbstractWordConverter.java
URL: http://svn.apache.org/viewvc/poi/trunk/src/scratchpad/src/org/apache/poi/hwpf/converter/AbstractWordConverter.java?rev=1160219&r1=1160218&r2=1160219&view=diff
==============================================================================
--- poi/trunk/src/scratchpad/src/org/apache/poi/hwpf/converter/AbstractWordConverter.java (original)
+++ poi/trunk/src/scratchpad/src/org/apache/poi/hwpf/converter/AbstractWordConverter.java Mon Aug 22 11:51:56 2011
@@ -324,7 +324,7 @@ public abstract class AbstractWordConver
 
             if ( structure.structure instanceof Bookmark )
             {
                 // other bookmarks with same bundaries
                 List<Bookmark> bookmarks = new LinkedList<Bookmark>();
                 for ( Bookmark bookmark : ( (HWPFDocument) wordDocument )
                         .getBookmarks()
@@ -379,8 +379,10 @@ public abstract class AbstractWordConver
         {
             if ( previous > range.getEndOffset() )
             {
-                logger.log( POILogger.WARN, "Latest structure in " + range
-                        + " ended after range (" + previous + ")" );
+                logger.log( POILogger.WARN, "Latest structure in ", range,
+                        " ended at #" + previous, " after range boundaries [",
+                        range.getStartOffset() + "; " + range.getEndOffset(),
+                        ")" );
                 return true;
             }
 



---------------------------------------------------------------------
@@ -324,7 +324,7 @@ public abstract class AbstractWordConver
             if ( structure.structure instanceof Bookmark )
             {
-                // other bookmarks with same bundaries
+                // other bookmarks with same boundaries
                 List<Bookmark> bookmarks = new LinkedList<Bookmark>();
                 for ( Bookmark bookmark : ( (HWPFDocument) wordDocument )
To unsubscribe, e-mail: commits-unsubscribe@poi.apache.org
For additional commands, e-mail: commits-help@poi.apache.org